package com.aucma.report.service;

import java.util.List;
import com.aucma.report.domain.MaterialCompletion;
import com.aucma.report.domain.ReportQualityInspection;

/**
 * 物料过点记录Service接口
 * 
 * @author Yinq
 * @date 2024-03-14
 */
public interface IMaterialCompletionService 
{
    /**
     * 查询物料过点记录
     * 
     * @param objId 物料过点记录主键
     * @return 物料过点记录
     */
    public MaterialCompletion selectMaterialCompletionByObjId(Long objId);

    /**
     * 查询物料过点记录列表
     * 
     * @param materialCompletion 物料过点记录
     * @return 物料过点记录集合
     */
    public List<MaterialCompletion> selectMaterialCompletionList(MaterialCompletion materialCompletion);

    /**
     * 新增物料过点记录
     * 
     * @param materialCompletion 物料过点记录
     * @return 结果
     */
    public int insertMaterialCompletion(MaterialCompletion materialCompletion);

    /**
     * 修改物料过点记录
     * 
     * @param materialCompletion 物料过点记录
     * @return 结果
     */
    public int updateMaterialCompletion(MaterialCompletion materialCompletion);

    /**
     * 批量删除物料过点记录
     * 
     * @param objIds 需要删除的物料过点记录主键集合
     * @return 结果
     */
    public int deleteMaterialCompletionByObjIds(Long[] objIds);

    /**
     * 删除物料过点记录信息
     * 
     * @param objId 物料过点记录主键
     * @return 结果
     */
    public int deleteMaterialCompletionByObjId(Long objId);

    /**
     * 二线质检存入过点数据
     * @param inspection
     */
    void inspectionProcessing(ReportQualityInspection inspection);
}
