package com.aucma.report.controller;

import java.util.List;
import javax.servlet.http.HttpServletResponse;

import com.aucma.common.utils.DateUtils;
import org.springframework.security.access.prepost.PreAuthorize;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.PutMapping;
import org.springframework.web.bind.annotation.DeleteMapping;
import org.springframework.web.bind.annotation.PathVariable;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RestController;
import com.aucma.common.annotation.Log;
import com.aucma.common.core.controller.BaseController;
import com.aucma.common.core.domain.AjaxResult;
import com.aucma.common.enums.BusinessType;
import com.aucma.report.domain.MaterialCompletion;
import com.aucma.report.service.IMaterialCompletionService;
import com.aucma.common.utils.poi.ExcelUtil;
import com.aucma.common.core.page.TableDataInfo;

/**
 * 物料过点记录Controller
 *
 * @author Yinq
 * @date 2024-03-14
 */
@RestController
@RequestMapping("/report/materialCompletion")
public class MaterialCompletionController extends BaseController {
    @Autowired
    private IMaterialCompletionService materialCompletionService;

    /**
     * 查询物料过点记录列表
     */
    @PreAuthorize("@ss.hasPermi('report:materialCompletion:list')")
    @GetMapping("/list")
    public TableDataInfo list(MaterialCompletion materialCompletion) {
        startPage();
        List<MaterialCompletion> list = materialCompletionService.selectMaterialCompletionList(materialCompletion);
        return getDataTable(list);
    }

    /**
     * 导出物料过点记录列表
     */
    @PreAuthorize("@ss.hasPermi('report:materialCompletion:export')")
    @Log(title = "物料过点记录", businessType = BusinessType.EXPORT)
    @PostMapping("/export")
    public void export(HttpServletResponse response, MaterialCompletion materialCompletion) {
        List<MaterialCompletion> list = materialCompletionService.selectMaterialCompletionList(materialCompletion);
        ExcelUtil<MaterialCompletion> util = new ExcelUtil<MaterialCompletion>(MaterialCompletion.class);
        util.exportExcel(response, list, "物料过点记录数据");
    }

    /**
     * 获取物料过点记录详细信息
     */
    @PreAuthorize("@ss.hasPermi('report:materialCompletion:query')")
    @GetMapping(value = "/{objId}")
    public AjaxResult getInfo(@PathVariable("objId") Long objId) {
        return success(materialCompletionService.selectMaterialCompletionByObjId(objId));
    }

    /**
     * 新增物料过点记录
     */
    @PreAuthorize("@ss.hasPermi('report:materialCompletion:add')")
    @Log(title = "物料过点记录", businessType = BusinessType.INSERT)
    @PostMapping
    public AjaxResult add(@RequestBody MaterialCompletion materialCompletion) {
        return toAjax(materialCompletionService.insertMaterialCompletion(materialCompletion));
    }

    /**
     * 修改物料过点记录
     */
    @PreAuthorize("@ss.hasPermi('report:materialCompletion:edit')")
    @Log(title = "物料过点记录", businessType = BusinessType.UPDATE)
    @PutMapping
    public AjaxResult edit(@RequestBody MaterialCompletion materialCompletion) {
        return toAjax(materialCompletionService.updateMaterialCompletion(materialCompletion));
    }

    /**
     * 删除物料过点记录
     */
    @PreAuthorize("@ss.hasPermi('report:materialCompletion:remove')")
    @Log(title = "物料过点记录", businessType = BusinessType.DELETE)
    @DeleteMapping("/{objIds}")
    public AjaxResult remove(@PathVariable Long[] objIds) {
        return toAjax(materialCompletionService.deleteMaterialCompletionByObjIds(objIds));
    }
}
